% Filtros para la reconstruccion IAP para el caso ENO.
%     capiacoefiiavp(nl,nr,r)
%     ENTRADAS:
%           nl=numero de nodos a la iquierda de x^{k}_{2i-1}
%           nr=numero de nodos a la derecha de x^{k}_{2i-1}
%           r= grado del polinomio IAP
%     SALIDAS:
%           muestra en pantalla los coeficientes que multiplican a f^{k-1} para obtenener f^{k}_{2i-1} mediante IA
%
% Autor: José Jaime Noguera.  +INFO: www.uv.es/anims/noguera

function capiacoefiiavp(nl,nr,r)

A=matriuiap(nl,nr,r);
C=(A'*A)^(-1)*A';
b0=[nl:-1:2,-1:-1:-nr+1]';
b1=[-nl+1:-1 , 2:nr]';

for i=2:r
   coef1(i)=1/2-1/(2^i);
   coef2(i)=1/(2^i)-1/2;
end 

bnlnr_1=(1-1/2+(coef1(2:r)*C*b0));
bnlnr0=(1/2+(coef1(2:r)*C*b1));
bnlnr=coef2(2:r)*C;

if(nl>=2 && nl>=2)
   solu=[bnlnr(1:nl-1),bnlnr_1,bnlnr0,bnlnr(nl:nl+nr-2)];
end

if(nl==1 && nr>=2)
   solu=[bnlnr_1,bnlnr0,bnlnr(nl:nl+nr-2)];
end

if(nl>=2 && nr==1)
   solu=[bnlnr(1:nl-1),bnlnr_1,bnlnr0];
end

format rational
  solu
format
sprintf('Comienza en f^{k-1}_{i+(%d)} y acaba en f^{k-1}_(i+(%d))',-nl,nr-1)